==> kbear-1.1.tar.gz: kbear-1.1/kbear/resource.h <==
/***************************************************************************
                          resource.h  -  description
                             -------------------
    begin                : Sat May 27 20:37:34 CEST 2000
    copyright            : (C) 2000 by Bjrn Sahlstrm
    email                : bjorn.sahlstrom@mail.bip.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef RESOURCE_H
#define RESOURCE_H

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif
	///////////////////////////////////////////////////////////////////
	// resource.h  -- contains some predefined strings
	///////////////////////////////////////////////////////////////////
	// General application values
	/*  */
	static const QString IDS_APPNAME = "KBear";
	/*  */
	static const QString IDS_AUTHOR = "Bjrn Sahlstrm";
	/*  */
	static const QString IDS_COPYRIGHT = "(c) 2000, Bjrn Sahlstrm";
	/*  */
	static const QString IDS_AUTHOR_EMAIL = "bjorn@kbear.org";
	/*  */
	static const QString IDS_HOMEPAGE = "http://www.kbear.org/";
	/*  */
	static QString IDS_STARTPAGE = IDS_HOMEPAGE;
#endif // RESOURCE_H

==> kbear_2.1.1.orig.tar.gz: kbear-2.1.1.orig/kbear/resource.h <==
/***************************************************************************
                          resource.h  -  description
                             -------------------
    begin                : sn jan 13 2002
    copyright            : (C) 2002 by Bjrn Sahlstrm
    email                : kbjorn@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef RESOURCE_H
#define RESOURCE_H

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif
#include <klocale.h>
	///////////////////////////////////////////////////////////////////
	// resource.h  -- contains some predefined strings
	///////////////////////////////////////////////////////////////////
	// General application values
	/*  */
	static const QString IDS_APPNAME = "KBear";
	/*  */
//	static const QString IDS_AUTHOR_1 = "Bjrn Sahlstrm";
	/*  */
	static const QString IDS_COPYRIGHT = "(C) 2002, The KBear team";
	/*  */
	static const QString IDS_AUTHOR_EMAIL = "kbjorn@users.sourceforge.net";
	static const QString IDS_AUTHOR_EMAIL2 = "tocool@telia.com";
	/*  */
	static const QString IDS_HOMEPAGE = "http://kbear.sourceforge.net/";
	static const double IDS_VERSION = 2.11; // this is used for version control of config file
#endif // RESOURCE_H
